# Python Packaging Repository for Github

This repository helps automate the development and deployment of Python packages to PyPI using GitHub workflows.

It is an instance of a Python Packaging Repository (PPR) created using the [`package-auto-assembler`](https://kiril-mordan.github.io/reusables/package_auto_assembler/) packaging tool. The repository is designed to streamline the development cycle of `single-module packages`, taking them from an initial idea to a functional alpha version accessible via [PyPI](https://pypi.org/).

Its highly automated CI/CD pipeline can package multiple packages stored in this repository, requiring as little as a single `.py` file, for basic designs. Learn more about this type of PPR [here](https://kiril-mordan.github.io/reusables/package_auto_assembler/python_packaging_repo/).

---

## Basic usage

Instuctions for the packaging repository include basics of how to:

1. Prepare Local Environment
2. Add or Edit a Package
3. Test-Install a Package
4. Push Changes to PPR
5. Publish a Package

These instructions could be accessed by vising [`package-auto-assembler` documentation](https://kiril-mordan.github.io/reusables/package_auto_assembler/python_packaging_repo/#basic-usage).

---

